@@ -58,7 +58,14 @@ class Make(object):
         print_depends = False
         if not SCons.GetOption('verbose'):
             print_depends = True
+        
+        # do user board pre config
         self.yoc = YoC()
+        result = self.yoc.doBoardPreConfig(board_name)
+        if result == True:
+            put_string("run user pre_config finish, rebuild compoments")
+            self.yoc = YoC()
+        
         solution = self.yoc.getSolution(board_name, print_depends=print_depends, exit_if_lost=False)
         if not solution:
             # retry if auto install missing component
