@@ -281,6 +281,7 @@ class build_config:
         self.submodule_script = ''
         self.prebuild_script = ''
         self.postbuild_script = ''
+        self.preconfig_script = ''
         self.postimage_script = ''
         # updated files after conditional depends
         self.include_updated = []
@@ -298,7 +299,7 @@ class build_config:
         text = ''
         for k in ['cflag', 'cxxflag', 'asmflag', 'ldflag', 'icc_cflag', 'icc_cxxflag', 'icc_asmflag', \
             'icc_ldflag', 'armcc_cflag', 'armcc_cxxflag', 'armcc_asmflag', 'armcc_ldflag', 'shldflag', \
-            'appldflag', 'shcflag', 'postimage_script', 'prebuild_script']:
+            'appldflag', 'shcflag', 'postimage_script', 'prebuild_script', 'preconfig_script']:
             value = self.__dict__[k]
             if value:
                 if len(value) < 60:
