@@ -39,8 +39,8 @@ all_toolchain_url = {
     'arm-ali-aoseabi': 'https://gitee.com/alios-things/gcc-arm-ali-aoseabi-linux.git',
     'riscv64-ali-aos': 'https://gitee.com/alios-things/gcc-riscv-ali-aos-linux.git',
     'xtensa-esp32-elf': 'https://hli.aliyuncs.com/o/config/esp32_toolchain/xtensa-esp32-elf-gcc8_4_0-esp-2020r3-linux-amd64.tar.gz',
-    # 'xtensa-esp32s2-elf': 'https://hli.aliyuncs.com/o/config/esp32_toolchain/xtensa-esp32s2-elf-gcc8_4_0-esp-2021r1-linux-amd64.tar.gz',
-    # 'xtensa-esp32s3-elf': 'https://hli.aliyuncs.com/o/config/esp32_toolchain/xtensa-esp32s3-elf-gcc8_4_0-esp-2021r2-linux-amd64.tar.gz',
+    'xtensa-esp32s2-elf': 'https://hli.aliyuncs.com/o/config/esp32_toolchain/xtensa-esp32s2-elf-gcc8_4_0-esp-2021r1-linux-amd64.tar.gz',
+    'xtensa-esp32s3-elf': 'https://hli.aliyuncs.com/o/config/esp32_toolchain/xtensa-esp32s3-elf-gcc8_4_0-esp-2021r2-linux-amd64.tar.gz',
     'riscv32-esp-elf': 'https://hli.aliyuncs.com/p/config/esp32_toolchain/riscv32-esp-elf-gcc8_4_0-esp-2021r2-linux-amd64.tar.gz'
     }, 
     'OSX':{
